export type PathEntry = {
    type: "object";
    key: string;
} | {
    type: "array";
    index: number;
} | {
    type: "string";
    index: number;
};
export type PathToCursor = PathEntry[];
export type JsonCursorPathOptions = {};
export declare class JsonCursorPath {
    private readonly code;
    private options;
    /**
     * Internal cursor position, used during parsing
     */
    private __cursorPosition;
    constructor(code: string, options?: JsonCursorPathOptions);
    get(cursorPosition: number, returnRawPath: true): PathToCursor;
    get(cursorPosition: number, returnRawPath?: false): string;
    /**
     * Convert a path to a string representation.
     * This should be compatible with third party libraries eg
     */
    rawPathToString(path: PathToCursor): string;
    /**
     * Parse an array. Place the index at the end square bracket or stop as soon as the cursor is found.
     */
    private parseArray;
    /**
     * Parse an object. Place the index at the end curly bracket or stop as soon as the cursor is found.
     */
    private parseObject;
    /**
     * Parse an object key. Place the index at the `:` before the value.
     */
    private parseObjectKey;
    /**
     * Parse any JSON value. Place the cursor at the separator after the value (could be one of `,]}`).
     */
    private parseValue;
    /**
     * Parse any litteral. Place the cursor at the end of the litteral (last char).
     */
    private parseAnyLitteral;
    /**
     * Return the first index of the next/prev specified token.
     * If not found, return the index of the end of the code (code.length) or -1 depending on the direction.
     */
    private parseUntilToken;
    /**
     * Whether the cursor position in within the specified bounds (includes these bounds)
     */
    private cursorWithin;
}
